"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAceCompatAutocompleter = exports.createCompletionResultForIdPrefix = exports.ID_REGEX = exports.mapMongoDBCompletionToCodemirrorCompletion = void 0;
const autocomplete_1 = require("@codemirror/autocomplete");
const autocompleter_1 = require("../autocompleter");
const utils_1 = require("./utils");
function mapMongoDBCompletionToCodemirrorCompletion(completion, escape = 'invalid') {
    const cmCompletion = {
        label: completion.value,
        apply: escape === 'never'
            ? completion.value
            : (0, autocompleter_1.wrapField)(completion.value, escape === 'always'),
        detail: completion.meta?.startsWith('field') ? 'field' : completion.meta,
        info() {
            if (!completion.description) {
                return null;
            }
            const infoNode = document.createElement('div');
            infoNode.classList.add('completion-info');
            infoNode.addEventListener('mousedown', (evt) => {
                if (evt.target.nodeName === 'A') {
                    evt.preventDefault();
                }
            });
            infoNode.innerHTML = completion.description;
            return infoNode;
        },
    };
    if (completion.snippet) {
        return (0, autocomplete_1.snippetCompletion)(completion.snippet, cmCompletion);
    }
    return cmCompletion;
}
exports.mapMongoDBCompletionToCodemirrorCompletion = mapMongoDBCompletionToCodemirrorCompletion;
exports.ID_REGEX = /[a-zA-Z_0-9$\-\u00A2-\u2000\u2070-\uFFFF]+/;
function createCompletionResultForIdPrefix({ prefix, completions, escape, }) {
    return {
        from: prefix.from,
        to: prefix.to,
        options: completions.map((completion) => {
            return mapMongoDBCompletionToCodemirrorCompletion(completion, escape);
        }),
        validFor: exports.ID_REGEX,
    };
}
exports.createCompletionResultForIdPrefix = createCompletionResultForIdPrefix;
function createAceCompatAutocompleter(completers) {
    return function aceCompatAutocompleter(context) {
        const prefix = context.matchBefore(exports.ID_REGEX);
        const token = (0, utils_1.resolveTokenAtCursor)(context);
        if (!prefix || prefix.text === '') {
            return null;
        }
        if (['BlockComment', 'LineComment'].includes(token.type.name)) {
            return null;
        }
        const opts = { context, prefix, token };
        if (token.type.name === 'String' && completers.String) {
            return completers.String(opts) ?? null;
        }
        return completers.IdentifierLike?.(opts) ?? null;
    };
}
exports.createAceCompatAutocompleter = createAceCompatAutocompleter;
//# sourceMappingURL=ace-compat-autocompleter.js.map