"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAggregationAutocompleter = void 0;
const mongodb_constants_1 = require("@mongodb-js/mongodb-constants");
const autocompleter_1 = require("../autocompleter");
const utils_1 = require("./utils");
const utils_2 = require("./utils");
const utils_3 = require("./utils");
const ace_compat_autocompleter_1 = require("./ace-compat-autocompleter");
const ace_compat_autocompleter_2 = require("./ace-compat-autocompleter");
const stage_autocompleter_1 = require("./stage-autocompleter");
const StageOperatorNames = new Set(mongodb_constants_1.STAGE_OPERATOR_NAMES);
function getStageNameForToken(editorState, token) {
    for (const parent of (0, utils_1.parents)(token)) {
        if (parent.name === 'Property') {
            const propertyName = (0, utils_2.getPropertyNameFromPropertyToken)(editorState, parent);
            if (parent.firstChild &&
                !(0, utils_2.isTokenEqual)(parent.firstChild, token) &&
                StageOperatorNames.has(propertyName)) {
                return propertyName;
            }
        }
    }
    return null;
}
function createAggregationAutocompleter(options = {}) {
    const stageAutocompletions = (0, autocompleter_1.completer)('', { ...options, meta: ['stage'] });
    return (0, ace_compat_autocompleter_2.createAceCompatAutocompleter)({
        IdentifierLike({ context, prefix, token }) {
            const stageOperator = getStageNameForToken(context.state, token);
            if (stageOperator) {
                return (0, stage_autocompleter_1.createStageAutocompleter)({ stageOperator, ...options })(context);
            }
            const isInsideBlock = token.name === 'PropertyName' || token.parent?.name === 'Property';
            return (0, ace_compat_autocompleter_1.createCompletionResultForIdPrefix)({
                prefix,
                completions: stageAutocompletions.map((completion) => {
                    const opName = completion.value;
                    return {
                        ...completion,
                        ...(completion.description && {
                            description: `<p>${(0, utils_3.aggLink)(opName)} pipeline stage</p>` +
                                `<p>${completion.description}</p>`,
                        }),
                        ...(completion.snippet && {
                            snippet: !isInsideBlock
                                ? `{\n${(0, utils_3.padLines)(`${opName}: ${completion.snippet}`)}\n}`
                                : `${opName}: ${completion.snippet}`,
                        }),
                    };
                }),
            });
        },
    });
}
exports.createAggregationAutocompleter = createAggregationAutocompleter;
//# sourceMappingURL=aggregation-autocompleter.js.map