"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDocumentAutocompleter = void 0;
const autocompleter_1 = require("../autocompleter");
const editor_1 = require("../editor");
const utils_1 = require("./utils");
function isJSONPropertyName(token) {
    return (token.name === 'PropertyName' ||
        (token.type.isError &&
            ['Property', '{'].includes(token.prevSibling?.name ?? '')));
}
function isJavaScriptPropertyName(token) {
    return (token.parent?.name === 'Property' &&
        (!token.prevSibling || token.prevSibling.name === '['));
}
const createDocumentAutocompleter = (fields) => {
    const completions = (0, autocompleter_1.completer)('', { fields, meta: ['field:identifier'] });
    return (context) => {
        const token = (0, utils_1.resolveTokenAtCursor)(context);
        const shouldAlwaysEscapeProperty = context.state.facet(editor_1.languageName)[0] === 'json';
        if (isJSONPropertyName(token) || isJavaScriptPropertyName(token)) {
            const prefix = context.state
                .sliceDoc(token.from, context.pos)
                .replace(/^("|')/, '');
            return {
                from: token.from,
                to: token.to,
                options: completions
                    .filter((completion) => {
                    return completion.value
                        .toLowerCase()
                        .startsWith(prefix.toLowerCase());
                })
                    .map((completion) => {
                    return {
                        label: (0, autocompleter_1.wrapField)(completion.value, shouldAlwaysEscapeProperty),
                        type: 'property',
                        detail: 'field',
                    };
                }),
                filter: false,
            };
        }
        return (0, utils_1.completeWordsInString)(context);
    };
};
exports.createDocumentAutocompleter = createDocumentAutocompleter;
//# sourceMappingURL=document-autocompleter.js.map