"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createSearchIndexAutocompleter = void 0;
const autocompleter_1 = require("../autocompleter");
const ace_compat_autocompleter_1 = require("./ace-compat-autocompleter");
const utils_1 = require("./utils");
const isCompletingFields = (ancestors) => {
    return ancestors[ancestors.length - 1] === 'fields';
};
const createSearchIndexAutocompleter = (options = {}) => {
    const completions = (0, autocompleter_1.completer)('', {
        meta: ['field:identifier'],
        ...options,
    });
    return (context) => {
        const token = (0, utils_1.resolveTokenAtCursor)(context);
        const document = context.state.sliceDoc(0);
        const prefix = context.matchBefore(ace_compat_autocompleter_1.ID_REGEX);
        if (!prefix) {
            return null;
        }
        const ancestors = (0, utils_1.getAncestryOfToken)(token, document);
        if (isCompletingFields(ancestors)) {
            return (0, ace_compat_autocompleter_1.createCompletionResultForIdPrefix)({
                prefix,
                completions,
            });
        }
        return (0, utils_1.completeWordsInString)(context);
    };
};
exports.createSearchIndexAutocompleter = createSearchIndexAutocompleter;
//# sourceMappingURL=search-index-autocompleter.js.map