"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createStageAutocompleter = void 0;
const autocompleter_1 = require("../autocompleter");
const ace_compat_autocompleter_1 = require("./ace-compat-autocompleter");
const utils_1 = require("./utils");
const query_autocompleter_1 = require("./query-autocompleter");
const createStageAutocompleter = ({ stageOperator, ...options } = {}) => {
    const queryAutocompleter = (0, query_autocompleter_1.createQueryAutocompleter)(options);
    const fieldsReferenceCompletions = (0, autocompleter_1.completer)('', {
        ...options,
        meta: ['field:reference'],
    });
    const stageCompletions = (0, autocompleter_1.completer)('', {
        ...options,
        meta: [
            'expr:*',
            'conv',
            'bson',
            'field:identifier',
            ...(['$project', '$group'].includes(stageOperator ?? '')
                ? ['accumulator', 'accumulator:*']
                : []),
        ],
    }).map((completion) => {
        if (completion.meta?.startsWith('expr:')) {
            return {
                ...completion,
                description: `<p>${(0, utils_1.aggLink)(completion.value)} pipeline operator</p>`,
            };
        }
        return completion;
    });
    return (0, ace_compat_autocompleter_1.createAceCompatAutocompleter)({
        String({ prefix, context }) {
            if (prefix.text.startsWith('$')) {
                return (0, ace_compat_autocompleter_1.createCompletionResultForIdPrefix)({
                    prefix,
                    completions: fieldsReferenceCompletions,
                    escape: 'never',
                });
            }
            return (0, utils_1.completeWordsInString)(context);
        },
        IdentifierLike({ prefix, context }) {
            if (stageOperator === '$match') {
                return queryAutocompleter(context);
            }
            return (0, ace_compat_autocompleter_1.createCompletionResultForIdPrefix)({
                prefix,
                completions: stageCompletions,
            });
        },
    });
};
exports.createStageAutocompleter = createStageAutocompleter;
//# sourceMappingURL=stage-autocompleter.js.map